@@ -1,7 +1,7 @@
 package RDF::DOAP::Resource;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = 0.005;
+our $VERSION   = 0.006;
 
 use Moose;
 
@@ -162,4 +162,14 @@ sub dump_json
 	);
 }
 
+sub isa
+{
+	my $self = shift;
+	
+	return grep($_[0]->equal($_), @{$self->rdf_type})
+		if Identifier->check(@_);
+	
+	$self->SUPER::isa(@_);
+}
+
 1;
